@@ -46,21 +46,22 @@ class ConfigUpgrader(log.Loggable):
             self._current_version = '0.1.7'
             
         self.releases = [(('0.1.7', ), self._update_0_1_to_0_3_1),
-                         (('0.3.1','0.3.1.1', ), self._update_0_3_1_to_0_3_2),
-                         (('0.3.2','0.3.2.1', ), self._update_0_3_2_to_0_3_3),
-                         (('0.3.3','0.3.3.1', '0.3.3.2',
+                         (('0.3.1', '0.3.1.1', ), self._update_0_3_1_to_0_3_2),
+                         (('0.3.2', '0.3.2.1', ), self._update_0_3_2_to_0_3_3),
+                         (('0.3.3', '0.3.3.1', '0.3.3.2',
                            '0.3.4.rc1', '0.3.4.rc2',),
                           self._update_0_3_3_to_0_3_4),
-                         (('0.3.4','0.3.4.1'), self._update_0_3_4_to_0_3_5),
+                         (('0.3.4', '0.3.4.1'), self._update_0_3_4_to_0_3_5),
                          (('0.5.7', '0.5.8'), self._update_0_5_7_to_0_5_8),
-                          ]
-        
+                         (('0.5.8', '0.5.9'), self._update_0_5_8_to_0_5_9),
+                        ]
+
     def _get_version_index_upgrade(self, version_str):
         idx = 0
         found_idx = 0
         to_call = None
         for versions, upgrade_call in self.releases:
-            if version_str in versions:
+            if version_str == versions[0]:
                 found_idx = idx
                 to_call = upgrade_call
                 break
@@ -79,27 +80,27 @@ class ConfigUpgrader(log.Loggable):
         # requested version
         idx, call = self._get_version_index_upgrade(self._current_version)
         while idx < len(self.releases) and call != None:
-                   
+
             if LooseVersion(self._current_version) >= loose_version:
                 break
-            
+
             cfg = call(cfg)
             updated = True
 
             # 0.3.4.rc* is considered superior to 0.3.4. So follows a
-            # wrokaround to avoid an infinite loop
+            # workaround to avoid an infinite loop
             if self._current_version == '0.3.4':
                if loose_version < LooseVersion('0.3.5'):
                    break
                else:
                    cfg = self._update_0_3_4_to_0_3_5(cfg)
-                   
+
             idx, call = self._get_version_index_upgrade(self._current_version)
-                
+
         if updated:
             cfg.set_option('install_date', self._today, section='general')
             cfg.set_option('version', version_str, section='general')
-            
+
             full_path = self._current_config.get_filename()
             cfg.set_filename(full_path)
             if os.path.exists(self._new_config_fname):
@@ -132,6 +133,24 @@ class ConfigUpgrader(log.Loggable):
         self.debug("Doing a backup to the old config on %s", full_path)
         cfg.write(full_path)
 
+    def _update_0_5_8_to_0_5_9(self, cfg=None):
+        self.info('Upgrading from 0.5.8 to 0.5.9')
+        self._backup((0, 5, 8), cfg)
+        if not cfg:
+            cfg = self._current_config
+
+        resource_providers = cfg.get_option('resource_providers',
+                                            section='general', default=[])
+        new_providers = ['search.search_metaresource_provider:SearchMetaresourceProvider',
+                         'yesfm.yesfm_resource:YesfmResource']
+        for provider in new_providers:
+            if provider not in resource_providers:
+                resource_providers = self._extend_list(resource_providers, 
+                                                       [provider])
+
+        self._current_version = '0.5.9'
+        return cfg
+
     def _update_0_5_7_to_0_5_8(self, cfg=None):
         self.info('Upgrading from 0.5.7 to 0.5.8')
         self._backup((0, 5, 7), cfg)
