@@ -36,21 +36,22 @@ EventType = enum.Enum('MOUSE_DOWN', 'MOUSE_UP', 'MOUSE_MOVE', 'KEY_DOWN',
                       'KEY_UP', 'OTHER')
 
 
-key_values = ['KEY_%s' % k for k in string.ascii_letters] + ['KEY_RETURN']
+key_values = ['KEY_%s' % k for k in string.ascii_letters] + ['KEY_RETURN'] + ['KEY_SPACE']
 num_values = ['KEY_%s' % k for k in string.digits]
 
 mouse_values = ['MOUSE_LEFT', 'MOUSE_MIDDLE', 'MOUSE_RIGHT',]
-values = key_values + num_values + mouse_values + ['NONE']
+
+special_key_values = ['KEY_GO_UP', 'KEY_GO_DOWN', 'KEY_GO_LEFT',
+                        'KEY_GO_RIGHT', 'KEY_OK', 'KEY_MENU', 'KEY_DVD_MENU',
+                        'KEY_EXIT', 'KEY_PLAY', 'KEY_PAUSE',
+                        'KEY_STOP', 'KEY_INC_PLAYBACK_SPEED',
+                        'KEY_DEC_PLAYBACK_SPEED', 'KEY_SEEK_FORWARD', 'KEY_SEEK_BACKWARD',
+                        'KEY_MUTE', 'KEY_VOL_UP', 'KEY_VOL_DOWN',
+                        'KEY_NEXT', 'KEY_PREVIOUS', 'KEY_PAGE_UP', 'KEY_PAGE_DOWN']
+
+values = key_values + num_values + mouse_values + special_key_values + ['NONE']
 EventValue = enum.Enum(*values)
 
-EventAction = enum.Enum('NONE', 'GO_UP', 'GO_DOWN', 'GO_LEFT',
-                        'GO_RIGHT', 'OK', 'MENU','DVD_MENU',
-                        'EXIT', 'PLAY', 'PAUSE',
-                        'STOP', 'INC_PLAYBACK_SPEED',
-                        'DEC_PLAYBACK_SPEED', 'SEEK_FORWARD',
-                        'SEEK_BACKWARD', 'TOGGLE_FULLSCREEN',
-                        'MUTE', 'VOL_UP', 'VOL_DOWN',
-                        'NEXT','PREVIOUS')
 EventModifier = enum.Enum('NONE', 'CTRL', 'SHIFT', 'ALT')
 
 
@@ -64,15 +65,12 @@ class InputEvent:
 
     @ivar source:    source device of the event (keyboard, mouse, ...)
     @ivar type:      type of event (KEY_UP, KEY_DOWN, ...)
-    @ivar action:    event's high level action (EXIT, PLAY, ...)
     @ivar value:     event's value (KEY_a, MOUSE_LEFT, ...)
     @ivar modifier:  event's modifier, especially useful for keyboards
-    @ivar source_id: source device id, 0 by default
     """
 
 
-    def __init__(self, source_type, event_type, action=EventAction.NONE,
-                 value=EventValue.NONE, source_id=None, modifier=EventModifier.NONE, origin=None):
+    def __init__(self, source_type, event_type, value=EventValue.NONE, modifier=EventModifier.NONE):
         """
         Create an InputEvent of a given type
 
@@ -82,15 +80,8 @@ class InputEvent:
         @type event_type:      L{EventType}
         @param value:          event's value (KEY_a, MOUSE_LEFT, ...)
         @type value:           L{EventValue}
-        @param action:         event's high level action
-        @type action:          L{EventAction}
-        @param source_id:      source device id, 0 by default
-        @type source_id:       int
         @param modifier:       event's modifier, especially useful for keyboards
         @type modifier:        L{EventModifier}
-        @param origin:         origin of the event
-        @type origin:          L{elisa.core.backend.Backend} or L{elisa.core.frontend.Frontend} or None
-
 
         @raise ValueError:     raised when either source, event_type
                                or value is None
@@ -105,26 +96,19 @@ class InputEvent:
         self.source = source_type
         self.type = event_type
         self.value = value
-        self.action = action
         self.modifier = modifier
-        self.source_id = source_id
-        self.origin = origin
 
     def __str__(self):
-        return "InputEvent from a %s (id=%s) with: type=%s, action=%s, value=%s, modifier=%s, origin=%s" \
-                % (self.source, self.source_id, self.type, \
-                    self.action, self.value, self.modifier, self.origin)
+        return "InputEvent from a %s with: type=%s, value=%s, modifier=%s" \
+                % (self.source, self.type, self.value, self.modifier)
 
     def __eq__(self, other):
         if not isinstance(other, InputEvent):
             return False
         return self.source == other.source and \
                self.type == other.type and \
-               self.action == other.action and \
                self.value == other.value and \
-               self.modifier == other.modifier and \
-               self.source_id == other.source_id and \
-               self.origin == other.origin 
+               self.modifier == other.modifier
 
     def __ne__(self, other):
         return not self.__eq__(other)
