@@ -23,7 +23,7 @@ from elisa.core import manager
 from elisa.core import input_event
 from elisa.core.utils import classinit
 from elisa.core.components.input_provider import PushInputProvider, PollInputProvider
-from twisted.internet import reactor
+from twisted.internet import reactor, task
 
 import gobject
 
@@ -52,9 +52,9 @@ class InputManager(manager.Manager,gobject.GObject):
         manager.Manager.__init__(self)
 
         # 35Hz polling rate for the PollInputProvider
-        self._polling_rate = 1 / 35.
-        self._polling = False
-        self._poll_call = None
+        self._poll_rate = 1 / 35.
+        self._poll_call = task.LoopingCall(self._poll_events)
+        self._running = False
 
     def start(self):
         """ Start a polling loop that will regularly check the registered
@@ -62,10 +62,8 @@ class InputManager(manager.Manager,gobject.GObject):
         L{elisa.core.input_event.InputEvent}s.
         """
         self.info("Starting")
-        self._polling = True
-        # start a looping callLater
-        self._poll_call = reactor.callLater(self._polling_rate,
-                                            self._poll_events)
+        self._running = True
+        self._check_polling()
 
     def stop(self):
         """ Clean all the registered
@@ -73,13 +71,12 @@ class InputManager(manager.Manager,gobject.GObject):
         polling for new L{elisa.core.input_event.InputEvent}s.
         """
         self.info("Stopping")
-        if self._poll_call:
-            try:
-                self._poll_call.cancel()
-            except:
-                pass
-        self._polling = False
-        manager.Manager.stop(self)
+        self._running = False
+
+        if self._poll_call is not None:
+            self._poll_call.stop()
+        
+        return manager.Manager.stop(self)
 
     def process_event(self, event):
         """ Fire the signal corresponding to the event.
@@ -116,6 +113,8 @@ class InputManager(manager.Manager,gobject.GObject):
             component.input_manager = self
             component.bind()
 
+        self._check_polling()
+
     def unregister_component(self, component):
         """ Clean the InputProvider and unregister it from the InputManager;
         no events from the InputProvider will be propagated anymore.
@@ -124,25 +123,36 @@ class InputManager(manager.Manager,gobject.GObject):
         @type component:  L{elisa.core.components.input_provider.InputProvider}
         """
         manager.Manager.unregister_component(self, component)
-        component.clean()
+        if isinstance(component, PushInputProvider):
+            component.unbind()
+        self._check_polling()
+
+    def _check_polling(self):
+        if not self._running:
+            return
+
+        have_poll = False
+        for component in self._components:
+            if isinstance(component, PollInputProvider):
+                have_poll = True
+                break
+
+        if have_poll and not self._poll_call.running:
+            self._poll_call.start(self._poll_rate)
+        elif self._poll_call.running:
+            self._poll_call.stop()
 
     def _poll_events(self):
         """ Poll each registered PollInputProvider for InputEvents to
         process.
         """
-        input_providers = filter(lambda p: isinstance(p, PollInputProvider),
-                                 self._components)
+        for component in self._components:
+            if not isinstance(component, PollInputProvider):
+                continue
 
-        for input_provider in input_providers:
-            events = input_provider.get_input_events()
+            events = component.get_input_events()
             for event in events:
                 self.process_event(event)
 
-        if self._polling:
-            self._poll_call = reactor.callLater(self._polling_rate,
-                                                self._poll_events)
-
-
-
 gobject.type_register(InputManager)
 
