@@ -24,8 +24,7 @@ __maintainer__ = 'Philippe Normand <philippe@fluendo.com>'
 from elisa.core import log, common, db_backend
 from elisa.extern import natural_sort
 from elisa.core.media_uri import MediaUri, quote, unquote
-from elisa.base_components.media_provider import NotifyEvent
-from elisa.core.observers.dict import DictObservable
+from elisa.core.components.media_provider import NotifyEvent
 
 
 CURRENT_DB_VERSION=1
@@ -638,7 +637,7 @@ class MediaDB(log.Loggable):
             for key in self.available_meta:
                 if key not in path_values.keys():
                     child_uri = uri_source + key
-                    metadata = DictObservable()
+                    metadata = dict()
                     children.append( (MediaUri(unicode(child_uri)), metadata) )
         else:   
             
@@ -663,7 +662,7 @@ class MediaDB(log.Loggable):
                 else:
                     child_uri = uri_source + quote(row[0])
 
-                metadata = DictObservable()
+                metadata = dict()
                 if select_attribute == 'albums':
                     metadata['album'] = row[0]
                     metadata['artist'] = self.get_artist_from_album(row[0])
