@@ -25,7 +25,7 @@ class MediaFile(object):
     This class provides a file-like API to access data at a given URI.
 
     MediaFiles are created by
-    L{elisa.base_components.media_provider.MediaProvider}
+    L{elisa.core.components.media_provider.MediaProvider}
     objects. They act as proxies to the latter, thus are bound to
     MediaProviders.
 
@@ -41,7 +41,7 @@ class MediaFile(object):
 
         @param media_provider: the Component which provides media access to the
                                descriptor, hence the media URI
-        @type media_provider:  L{elisa.base_components.media_provider.MediaProvider}
+        @type media_provider:  L{elisa.core.components.media_provider.MediaProvider}
         @param descriptor:     media descriptor symbolizing the opened media
         @type descriptor:      object
         """
