@@ -22,7 +22,7 @@ __maintainer__ = 'Philippe Normand <philippe@fluendo.com>'
 
 
 import os, re, urllib, platform, copy
-from elisa.core.utils import classinit
+from elisa.core.utils import classinit, locale_helper
 
 # for i18n support
 from elisa.extern.translation import Translatable
@@ -46,7 +46,7 @@ def quote(data, not_quote=''):
     simply returned.
 
     Warning: If you want to quote a path containing '/' as seperators, you
-    have to add the slash to not_quote, or it will be quoted also!!! 
+    have to add the slash to not_quote, or it will be quoted also!!!
 
     @param data: unquoted data which can contain unsafe characters like &=
     @type data:  string, list or dict
@@ -54,23 +54,25 @@ def quote(data, not_quote=''):
     @type not_quote: string
     @rtype:      string, list or dict
     """
+    sys_encoding = locale_helper.system_encoding()
+
     if isinstance(data, basestring):
         if isinstance(data, unicode):
             # urllib.quote doesn't support unicode objects very well
-            data = data.encode('utf-8')
+            data = data.encode(sys_encoding)
         quoted = urllib.quote(data, not_quote)
     elif isinstance(data, dict):
         quoted = {}
         for k, v in data.iteritems():
             if isinstance(v, unicode):
                 # urllib.quote doesn't support unicode objects very well
-                v = v.encode('utf-8')
+                v = v.encode(sys_encoding)
             quoted[k] = urllib.quote(v, not_quote)
     elif isinstance(data, list):
         quoted = []
         for entry in data:
             if isinstance(entry, unicode):
-                entry = entry.encode('utf-8')
+                entry = entry.encode(sys_encoding)
             quoted.append(urllib.quote(entry, not_quote))
     elif isinstance(data, int):
         ## FIXME: do we need this/should we do this ?
@@ -88,8 +90,9 @@ def unquote(data):
 
     @param data: quoted data
     @type data:  string, list or dict
-    @rtype:      string, list or dict of unicodes 
+    @rtype:      string, list or dict of unicodes
     """
+
     if isinstance(data, basestring):
         if isinstance(data, unicode):
             # urllib.quote doesn't support unicode objects very well
@@ -114,21 +117,23 @@ def unquote(data):
 
 def _unicode(data):
     """
-    Convert data to unicode using utf-8 encoding instead of ascii.
+    Convert data to unicode using system encoding instead of ascii.
 
     @param data: data to convert
     @type data:  string, unicode or other object
     @rtype:      unicode
     """
+    sys_encoding = locale_helper.system_encoding()
+
     if isinstance(data, unicode):
         result = data
     elif isinstance(data, str):
-        result = unicode(data, 'utf-8')
+        result = unicode(data, sys_encoding)
     else:
-        result = unicode(str(data), 'utf-8')
+        result = unicode(str(data), sys_encoding)
     return result
-        
-        
+
+
 
 class MediaUri:
     """ Media URI management
@@ -200,13 +205,15 @@ class MediaUri:
         self._label = u''
         self._params = {}
 
+        sys_encoding = locale_helper.system_encoding()
+
         if isinstance(data, MediaUri):
             # copycat, avoid another parse
             if data.path.find('\\') != -1:
                 path = data.path.replace('\\', '/')
             else:
                 path = data.path
-                
+
             uri_parts = {'scheme': data.scheme, 'user': data.user,
                          'password': data.password, 'host': data.host,
                          'port': data.port, 'path': path,
@@ -218,13 +225,17 @@ class MediaUri:
             if data.has_key('path') and data['path'].find('\\') != -1:
                 data['path'] = data['path'].replace('\\', '/')
             uri_parts = data
-        elif isinstance(data, str):
-            
+        elif isinstance(data, str) or isinstance(data, unicode):
             if data.find('\\') != -1:
-                data = data.replace('\\', '/')            
-            location = unicode(data, 'utf-8')
-        elif isinstance(data, unicode):
-            location = data
+                data = data.replace('\\', '/')
+            if data.startswith('file://') and data.startswith('file:///') \
+                == False and data.startswith('file://./') == False:
+                data = "%s/%s" % (data[0:7], data[7:])
+
+            if isinstance(data, str):
+                location = unicode(data, sys_encoding)
+            else:
+                location = data
 
         if uri_parts:
             # FIXME: scheme cannot be empty according to the docstring
@@ -263,15 +274,17 @@ class MediaUri:
         return URI_RE
 
     def path__get(self):
-        if platform.system() == 'Windows' and len(self._path) > 0 and self._path[0] == '/' and self.scheme == 'file':
-            return self._path[1:]
+        if platform.system() == 'Windows':
+            if ((len(self._path) > 1 and self._path[0] == '/' and self._path[1] != "/") or \
+                len(self._path) == 1) and (self.scheme == 'file' or self.scheme == 'ipod'):
+                return self._path[1:]
         return self._path
-    
+
     def path__set(self, value):
         self._path = value
-    
+
     def _parse(self, location):
-        
+
         system_name = platform.system()
         match = self._uri_re().search(location)
         if match:
@@ -335,14 +348,11 @@ class MediaUri:
                     # path should always start with /
                     path = "/%s" % path
 
-                #remove double // in path
-                path = path.replace('//','/')
-                
             self._path = _unicode(path)
 
             if params:
                 key_values = params.split('&')
-                
+
                 # ?foo special case
                 if key_values[0].find('=') == -1:
                     key_values = [ "%s=" % key_values[0], ]
@@ -570,8 +580,9 @@ class MediaUri:
 
         @rtype: string
         """
+        sys_encoding = locale_helper.system_encoding()
         r = self._to_unicode()
-        r = r.encode('utf-8')
+        r = r.encode(sys_encoding)
         return r
 
     __repr__ = __str__
