@@ -35,7 +35,8 @@ class Options(usage.Options):
                 ['twisted-version', '', 'show twisted version'],
                 ['tracebacks', 't', 'display tracebacks'],
                 ['log', 'l', 'log output in elisa.log files'],
-                ['shell', '', 'open an interactive shell in the terminal']
+                ['shell', '', 'open an interactive shell in the terminal'],
+                ['headless', '', 'start in headless mode']
                 ]
     
     optParameters = [["import", "i", None, "The script to import, used by \
