@@ -18,8 +18,8 @@
 __maintainer__ = 'Benjamin Kampmann <benjamin@fluendo.com>'
 
 
-from elisa.core.bus import bus
-from elisa.base_components import message
+from elisa.core import bus
+from elisa.core.components import message
 from elisa.core import common, log
 from elisa.extern import enum
 
