@@ -36,7 +36,7 @@ class NoEngineFound(Exception):
 class PlayerEngineRegistry(log.Loggable):
     """
     The PlayerEngineRegistry has the responsability to create
-    L{elisa.base_components.player_engine.PlayerEngine} instances
+    L{elisa.core.components.player_engine.PlayerEngine} instances
     given URI schemes.
     """
 
@@ -106,7 +106,7 @@ class PlayerEngineRegistry(log.Loggable):
         @raise:         L{elisa.core.player_engine_registry.NoEngineFound}
                         if no engine is found
 
-        @rtype:         L{elisa.base_components.player_engine.PlayerEngine} or
+        @rtype:         L{elisa.core.components.player_engine.PlayerEngine} or
                         None
         """
         self.debug("Creating new engine for %s" % scheme)
