@@ -49,7 +49,7 @@ class ServiceManager(manager.Manager):
         """ Clean a ServiceProvider and unregister it from the ServiceManager.
 
         @param component: the ServiceProvider instance to unregister
-        @type component:  L{elisa.base_components.service_provider.ServiceProvider}
+        @type component:  L{elisa.core.components.service_provider.ServiceProvider}
 
         @raise CannotUnregister : raised when the component cannot be removed
         """
