@@ -16,8 +16,6 @@
 from elisa.extern.translation import Translator
 
 from elisa.core import log, common
-#FIXME : BAD HACK to disable the reactor installation in test mode 
-common.from_test = True
 
 from elisa.core import application
 from elisa.core import config, plugin_registry
@@ -25,10 +23,7 @@ from elisa.core import interface_controller
 from elisa.core import media_manager
 from elisa.core import metadata_manager
 from elisa.core import input_manager
-from elisa.core import plugin
-from elisa.core.bus import bus
-from elisa.base_components import view, context, activity, model, controller,\
-     theme
+from elisa.core import bus
 from elisa.extern.log import log as extern_log
 
 from twisted.trial import unittest
@@ -44,8 +39,6 @@ media_providers = []
 metadata_providers = []
 service_providers = []
 player_engines = []
-backends = ['backend1']
-frontends = ['frontend1']
 
 [media_db:media_scanner]
 enabled = '1'
@@ -59,16 +52,6 @@ unmonitored_locations = []
 db_backend = 'sqlite'
 database = 'elisa.db'
 
-[backend1]
-activity = 'test:elisa_activity'
-mvc_mappings = 'test_mvc_mappings.conf'
-input_providers = []
-
-[frontend1]
-backend = 'backend1'
-theme = 'test:test_theme'
-input_providers = []
-
 [xmlmenu:locations_builder]
 locations = []
 auto_locations = 1
@@ -85,62 +68,12 @@ controlpoint = 'yes'
 
 [[plugins]]
 
-[base:service_activity]
-# a list of activites, which should beappear in the service_menu
-service_activities = ['service:about_activity']
-
 [player]
 audiosink = 'autoaudiosink'
 
-[theme_switcher:theme_switcher_activity]
-# a list of themes 'plugin:component' like 'classic:theme'
-themes = ['poblenou:tango_theme', 'poblenou:poblenou_theme', 'poblenou:chris_theme']
 """
 
 
-MAPPINGS="""\
-[test:elisa_model]
-supported_controllers = ['test:elisa_controller',]
-controller = 'test:elisa_controller'
-supported_views = ['test:elisa_view']
-view = 'test:elisa_view'
-"""
-
-class TestTheme(theme.Theme):
-    name = 'test_theme'
-
-class TestModel(model.Model):
-    name = 'elisa_model'
-    path = 'test:elisa_model'
-    
-class TestController(controller.Controller):
-    name = 'elisa_controller'
-    supported_models = ('test:elisa_model',)
-
-class TestActivity(activity.Activity):
-    name = 'elisa_activity'
-
-    def get_model(self):
-        return TestModel()
-
-class TestView(view.View):
-    name = 'elisa_view'
-    context_path = 'test:elisa_context'
-    supported_controllers = ('test:elisa_controller',)
-    
-class TestContext(context.Context):
-    name = 'elisa_context'
-    
-class TestPlugin(plugin.Plugin):
-    name = 'test'
-    components = {'elisa_model': {'path': TestModel},
-                  'elisa_controller': {'path': TestController},
-                  'elisa_view': {'path': TestView},
-                  'elisa_context': {'path': TestContext},
-                  'elisa_activity': {'path': TestActivity},
-                  'test_theme': {'path': TestTheme},
-                  }
-    
 class BoilerPlateApp:
 
     def __init__(self, config_file, default_config=None, load_all_plugins=False):
@@ -158,7 +91,6 @@ class BoilerPlateApp:
         manager = plugin_registry.PluginRegistry(self.config)
         if load_all_plugins:
             manager.load_plugins()
-        manager.register_plugin(TestPlugin)
         
         self.plugin_registry = manager
         self.bus = bus.Bus()
@@ -199,15 +131,9 @@ class ElisaTestCase(unittest.TestCase, extern_log.Loggable):
 
     def _boot(self):
         if self._booted == False:
-            common.boot()
-
             if 'ELISA_DEBUG' not in os.environ:
                 log.setDebug('*:0')
 
-            f = open('test_mvc_mappings.conf','w')
-            f.write(MAPPINGS)
-            f.close()
-
             app = BoilerPlateApp('empty.conf', self.default_config,
                                  self.load_all_plugins)
             self.debug("Set common.application to %r", app)
