@@ -25,7 +25,7 @@ class TestApplication(ElisaTestCase):
     def setUp(self):
         ElisaTestCase.setUp(self)
         self.app = Application('test.conf')
-        
+ 
     def test_default_config(self):
         """ Load the default config file
         """
@@ -35,13 +35,14 @@ class TestApplication(ElisaTestCase):
             pass
 
         default_config = DEFAULT_CONFIG % {'version': 'test',
-                                           'install_date': 'none'}
+                                           'install_date': 'none',
+                                           'database_uri': 'sqlite:'}
         c = config.Config('test.conf', default_config)
         self.assertEqual(c.get_filename(), 'test.conf')
         self.assertEqual(c.get_config_dir(), os.getcwd())
         c.write()
         f = open('test.conf')
-        self.assertEqual(f.read(), default_config)
+        self.assertEqual(f.read().splitlines(), default_config.splitlines())
 
     def test_create_config_dir(self):
         """
@@ -67,6 +68,9 @@ class TestApplication(ElisaTestCase):
 
     test_create_config_dir.skip = "Shall we really interact with the developer's filesystem ?"
 
+    def test_deferred_store(self):
+        """ test whether the default sqlite database setup works """
+        return self.app.initialize_db()
 
     def test_attributes(self):
 
