@@ -34,16 +34,26 @@ class TestConfigUpgrader(ElisaTestCase):
         upgrader = config_upgrader.ConfigUpgrader(old_config, default)
         cfg = upgrader.update_for(version)
 
-        cfg_version = cfg.get_option('version', section='general')
+        cfg_version = cfg.get_option('version', section='general',
+                                     default='0.1.7')
         version_str = '.'.join([str(i) for i in version])        
         self.assertEquals(cfg_version, version_str)
         return cfg
 
+    def _assert_0_1_7(self, cfg):
+        pass
+
+    def _assert_0_3_1(self, cfg):
+        pass
+
     def _assert_0_3_2(self, cfg):
+        media_providers = cfg.get_option('media_providers')
         for path in ['base:local_media', 'coherence_plugin:upnp_media',
                      'media_good:gnomevfs_media', 'media_bad:ipod_media',
                      'media_good:elisa_media', 'audiocd:audiocd_media']:
-            self.failIf(path not in cfg.get_option('media_providers'))
+            self.failIf(path not in media_providers,
+                        '%s not in media_providers %r' % (path,
+                                                          media_providers) )
 
         for path in ['media_good:amazon_covers', 'media_good:taglib_metadata',
                      'media_good:cover_cache', 'media_good:gst_metadata',
@@ -143,14 +153,15 @@ class TestConfigUpgrader(ElisaTestCase):
                                                    default=[]))
             
         service_providers = ['media_db:media_scanner',
-                             'osso:osso_service',
-                             'updater:updater_service']
+                             'osso:osso_service']
         cfg_service_providers = cfg.get_option('service_providers',
                                                default=[])
         for path in service_providers:
             self.failIf(path not in cfg_service_providers,
                         "%r not in service_providers %r" % (path,
                                                             cfg_service_providers))
+        self.failIf('updater:updater_service' in cfg_service_providers,
+                    "elisa updater service should be disabled for 0.3.4 release")
 
         removed_sections = ['media_scanner',]
         for section_name in removed_sections:
@@ -161,54 +172,29 @@ class TestConfigUpgrader(ElisaTestCase):
             self.assertEqual(show_fps, '0')
 
     def _assert_0_3_5(self, cfg):
-        service_providers = ['updater:updater_service',]
-        cfg_service_providers = cfg.get_option('service_providers',
-                                               default=[])
-        for path in service_providers:
-            self.failIf(path not in cfg_service_providers,
-                        "%r not in service_providers %r" % (path,
-                                                            cfg_service_providers))
+        removed_sections = ['base:player_controller',
+                            'poblenou:player_view']
+        for section_name in removed_sections:
+            self.failIf(cfg.get_section(section_name))
 
-    def testUpgrade0_1_7To_0_3_1(self):
-        " 0.1.7 -> 0.3.1 "
-        self._upgrade('elisa_0_1_7.conf', 'elisa_0_3_1.conf', (0, 3, 1))
+    def _assert_0_3_6(self, cfg):
+        pass
 
-    def testUpgrade0_1_7To_0_3_2(self):
-        " 0.1.7 -> 0.3.2 "
-        self._upgrade('elisa_0_1_7.conf','elisa_0_3_2.conf', (0, 3, 2))
-        
-    def testUpgrade0_1_7To_0_3_3(self):
-        " 0.1.7 -> 0.3.3 "
-        self._upgrade('elisa_0_1_7.conf','elisa_0_3_3.conf', (0, 3, 3))
+    def test_upgrades(self):
+        to_check = []
+        upgrader = config_upgrader.ConfigUpgrader(None, None)
+        for versions, call in upgrader.releases:
+            version = versions[0]
+            version_tuple = tuple(version.split('.'))
+            assert_method = getattr(self,
+                                    '_assert_%s' % '_'.join(version_tuple))
+            to_check.append((version_tuple, assert_method))
 
-    def testUpgrade0_1_7To_0_3_4(self):
-        " 0.1.7 -> 0.3.4 "
-        self._upgrade('elisa_0_1_7.conf','elisa_0_3_4.conf', (0, 3, 4))
-        
-    def testUpgrade0_1_7To_0_3_5(self):
-        " 0.1.7 -> 0.3.5 "
-        self._upgrade('elisa_0_1_7.conf','elisa_0_3_5.conf', (0, 3, 5))
-        
-    def testUpgrade0_3_1To_0_3_2(self):
-        " 0.3.1 -> 0.3.2 "
-        cfg = self._upgrade('elisa_0_3_1.conf', 'elisa_0_3_2.conf', (0, 3, 2))
-        self._assert_0_3_2(cfg)
-
-    def testUpgrade0_3_2To_0_3_3(self):
-        " 0.3.2 -> 0.3.3 "
-        cfg = self._upgrade('elisa_0_3_2.conf', 'elisa_0_3_3.conf', (0, 3, 3))
-        self._assert_0_3_3(cfg)
-
-    def testUpgrade0_3_3To_0_3_4(self):
-        " 0.3.3 -> 0.3.4 "
-        cfg = self._upgrade('elisa_0_3_3.conf', 'elisa_0_3_4.conf', (0, 3, 4))
-        self._assert_0_3_4(cfg)
-
-        cfg = self._upgrade('elisa_0_3_3.conf', 'elisa_0_3_4.conf',
-                            (0, 3, 4, 'rc1'))
-        self._assert_0_3_4(cfg)
-
-    def testUpgrade0_3_4To_0_3_5(self):
-        " 0.3.5 -> 0.3.5 "
-        cfg = self._upgrade('elisa_0_3_4.conf', 'elisa_0_3_5.conf', (0, 3, 5))
-        self._assert_0_3_5(cfg)
+        for item in to_check:
+            idx = to_check.index(item)
+            version_tuple, do_assert = item
+            for up_version_tuple, up_do_assert in to_check[idx+1:]:
+                old_conf = 'elisa_%s.conf' % '_'.join(version_tuple)
+                new_conf = 'elisa_%s.conf' % '_'.join(up_version_tuple)
+                cfg = self._upgrade(old_conf, new_conf, up_version_tuple)
+                up_do_assert(cfg)
