@@ -14,9 +14,8 @@
 # for details on that license.
 
 from elisa.core.tests.elisa_test_case import ElisaTestCase
-from elisa.core import plugin
 from elisa.core import media_manager, metadata_manager, media_uri
-from elisa.base_components import media_provider, metadata_provider
+from elisa.core.components import media_provider, metadata_provider
 from elisa.core.tests.test_metadata_provider import FooMetadataProvider
 import tempfile, shutil, os, tempfile
 
@@ -32,33 +31,17 @@ class AnotherFooMediaProvider(media_provider.MediaProvider):
     def supported_uri_schemes__get(self):
         return {'foo': 2, 'bar': 0}
 
-class FooPlugin(plugin.Plugin):
-    name = 'foo'
-    components = {'foo_media_provider': {'path': FooMediaProvider}}
-
-class FooPlugin2(plugin.Plugin):
-    name = 'foo2'
-    components = {'another_foo_media_provider': {'path':AnotherFooMediaProvider},
-                  'foo_metadata_provider': {'path': FooMetadataProvider}}
-    
 class TestMediaManager(ElisaTestCase):
     def setUp(self):
         ElisaTestCase.setUp(self)
 
-        from elisa.core.common import application
-##         application.plugin_registry.register_plugin(LFS)
-        application.plugin_registry.register_plugin(FooPlugin)
-        application.plugin_registry.register_plugin(FooPlugin2)
-
-        c = application.plugin_registry.create_component
-
         self._metadata_manager = metadata_manager.MetadataManager()
-        self._metadata_manager.register_component(c('foo2:foo_metadata_provider'))
+        self._metadata_manager.register_component(FooMetadataProvider())
 
         self._media_manager = media_manager.MediaManager(self._metadata_manager)
 
-        self._media_manager.register_component(c('foo:foo_media_provider'))
-        self._media_manager.register_component(c('foo2:another_foo_media_provider'))
+        self._media_manager.register_component(FooMediaProvider())
+        self._media_manager.register_component(AnotherFooMediaProvider())
 
         self._media_manager.start()     
         
