@@ -19,7 +19,7 @@ from twisted.trial import unittest
 from elisa.core.tests.component_test_case import ComponentTestCase
 from elisa.core.media_uri import MediaUri
 
-from elisa.base_components.media_provider import MediaProvider, media_types
+from elisa.core.components.media_provider import MediaProvider, media_types
 
 class TestMediaProvider(ComponentTestCase):
 
