@@ -15,6 +15,7 @@
 # for details on that license.
 
 from elisa.core import media_uri
+from elisa.core.utils import locale_helper
 from elisa.core.tests.elisa_test_case import ElisaTestCase
 import os, platform
 
@@ -37,7 +38,6 @@ class TestMediaURI(ElisaTestCase):
 
     def test_samples(self):
         for url in self.samples:
-            #url.encode("utf-8")
             try:
                 uri = media_uri.MediaUri(url)
             except Exception, exc:
@@ -61,7 +61,7 @@ class TestMediaURI(ElisaTestCase):
         loc = "daap://192.168.1.73:3689"
         uri = media_uri.MediaUri(loc)
         self.assertEquals(uri.port, 3689)
-        
+
         #Empty port
         loc = "daap://192.168.1.73:/"
         uri = media_uri.MediaUri(loc)
@@ -70,47 +70,63 @@ class TestMediaURI(ElisaTestCase):
     def test_windows_path(self):
         uri = media_uri.MediaUri(u'file:///c:/home/phil/foo.mp3')
         self.assertEqual(str(uri), 'file:///c:/home/phil/foo.mp3')
-        
+
         if platform.system() == 'Windows':
             self.assertEqual(uri.path, u'c:/home/phil/foo.mp3')
         else:
             self.assertEqual(uri.path, u'/c:/home/phil/foo.mp3')
-            
+
         uri_parts = {'scheme': 'file',
                      'path': "c:\\home\\phil\\foo.mp3"
                     }
         uri = media_uri.MediaUri(uri_parts)
         self.assertEqual(str(uri), 'file:///c:/home/phil/foo.mp3')
-            
+
+        uri = media_uri.MediaUri(u'file://c:/home/phil/foo.mp3')
+        self.assertEqual(str(uri), 'file:///c:/home/phil/foo.mp3')
+
+        if platform.system() == 'Windows':
+            self.assertEqual(uri.path, u'c:/home/phil/foo.mp3')
+        else:
+            self.assertEqual(uri.path, u'/c:/home/phil/foo.mp3')
+
+        uri_parts = {'scheme': 'file',
+                     'path': "c:\\home\\phil\\foo.mp3"
+                    }
+        uri = media_uri.MediaUri(uri_parts)
+        self.assertEqual(str(uri), 'file:///c:/home/phil/foo.mp3')
+
         uri = media_uri.MediaUri(u'http:///')
         self.assertEqual(str(uri), 'http:///')
         self.assertEqual(uri.path, '/')
-        
+
         uri = media_uri.MediaUri(u'http://')
         self.assertEqual(str(uri), 'http://')
         self.assertEqual(uri.path, '')
-        
+
         uri = media_uri.MediaUri(u'file:///')
         self.assertEqual(str(uri), u'file:///')
         if platform.system() == 'Windows':
             self.assertEqual(uri.path, u'')
         else:
             self.assertEqual(uri.path, u'/')
-            
-        uri = media_uri.MediaUri(u'file:////')
-        self.assertEqual(str(uri), u'file:///')
+
         if platform.system() == 'Windows':
             self.assertEqual(uri.path, u'')
         else:
             self.assertEqual(uri.path, u'/')
 
+        uri = media_uri.MediaUri(u"file:///c:\\home\\phil\\foo.mp3")
+        self.assertEqual(str(uri), 'file:///c:/home/phil/foo.mp3')
+        self.assertEqual(uri.filename, 'foo.mp3')
+
     def test_escape(self):
         uri = media_uri.MediaUri(u'file:///home/phil/foo?.mp3')
         if platform.system() == 'Windows':
             self.assertEqual(uri.path, u'home/phil/foo')
         else:
             self.assertEqual(uri.path, u'/home/phil/foo')
-            
+
         uri = media_uri.MediaUri(u'file:///c:/home/phil/foo?.mp3')
         if platform.system() == 'Windows':
             self.assertEqual(uri.path, u'c:/home/phil/foo')
@@ -118,10 +134,6 @@ class TestMediaURI(ElisaTestCase):
             self.assertEqual(uri.path, u'/c:/home/phil/foo')
 
     def test_smb(self):
-        
-        if platform.system() == 'Windows':
-            raise unittest.SkipTest("Does not works under windows, need investigation")
-        
         uri = media_uri.MediaUri(u"smb://philn:foo@phil/bare")
         expected_parts = {u'password': u'foo', u'fragment': u'',
                           u'host': u'phil', u'path':u'/bare',
@@ -130,7 +142,7 @@ class TestMediaURI(ElisaTestCase):
         for k, v in expected_parts.iteritems():
             fail = "%s value unexpected: %r. got %r" % (k,v, getattr(uri, k))
             self.assertEquals(getattr(uri, k), v, fail)
-    
+
     def test_unicode(self):
         u = u'file:///home/phil/\ufffd'
         uri = media_uri.MediaUri(u)
@@ -147,7 +159,7 @@ class TestMediaURI(ElisaTestCase):
             self.assertEquals(uri.path, u'path/to/some_where - †')
         else:
             self.assertEquals(uri.path, u'/path/to/some_where - †')
-        
+
         self.assertEquals(uri.scheme, u'file')
 
 ##         u = u'file:///home/phil/\ufffd'
@@ -157,7 +169,7 @@ class TestMediaURI(ElisaTestCase):
     def test_no_unicode(self):
         u = 'file:///Vidéos'
         uri = media_uri.MediaUri(u)
-        self.assertEqual(unicode(uri), unicode(u, 'utf-8'))
+        self.assertEqual(unicode(uri), unicode(u, locale_helper.system_encoding()))
 
     def test_parameters(self):
         location = u'http://192.168.2.69:10243/WMCv2/%7b9B3A580F-68E8-4701-B8D8-9708E6E5E4F6%7d/103-1.wma?format=PCM'
@@ -169,7 +181,7 @@ class TestMediaURI(ElisaTestCase):
         uri = media_uri.MediaUri(location)
         parameters =  {u'formatID':u'24', u'width': u'684',
                                       u'height':u'456'}
- 
+
         for key in parameters.keys():
             self.assertEqual(uri.get_param(key), parameters[key])
 
@@ -250,12 +262,12 @@ class TestMediaURI(ElisaTestCase):
     def test_back_slash(self):
         uri = media_uri.MediaUri("file:///test/foo\\x")
         self.assertEqual(str(uri), 'file:///test/foo/x')
-        
+
         parts = {'scheme': 'file', 'path': "/test/foo\\x"}
         uri = media_uri.MediaUri(parts)
         self.assertEqual(str(uri), 'file:///test/foo/x')
-        
-        
+
+
     def test_unquoting(self):
         unquoted = '12345 6789'
         to_unquote = '12345%206789'
@@ -283,7 +295,7 @@ class TestMediaURI(ElisaTestCase):
         cwd = os.getcwd()
         if platform.system() == 'Windows':
             cwd = '/' + cwd.replace('\\', '/')
-        
+
         self.assertEqual(repr(uri), u'file://%s/test/toto' % cwd)
 
     def test_uri_parts(self):
@@ -316,7 +328,7 @@ class TestMediaURI(ElisaTestCase):
         uri = media_uri.MediaUri(uri_parts)
         loc = u'scheme://user:password@host.com:80/test- † -html?param2=2&param1=1#truc'
 #        self.assertEqual(uri.path,u'/test- † -html')
-        self.assertEqual(repr(uri), loc.encode('utf-8'))
+        self.assertEqual(repr(uri), loc.encode(locale_helper.system_encoding()))
 
     def test_partial_uri_parts(self):
         uri = media_uri.MediaUri({'scheme':'file', 'path': u'/tmp'})
@@ -426,7 +438,7 @@ class TestMediaURI(ElisaTestCase):
             self.assertEqual(root_uri1.path, '')
         else:
             self.assertEqual(root_uri1.path, '/')
-        
+
 
         root_loc2 = 'file://'
         root_uri2 = media_uri.MediaUri(root_loc2)
@@ -450,7 +462,7 @@ class TestMediaURI(ElisaTestCase):
         uri.label = u"truc"
         self.failUnless(isinstance(uri.label, unicode))
         self.assertEqual(uri.label, u"truc")
-    
+
     def test_uri_from_uri(self):
         loc = u'http://example.net/?ciao=miao'
         uri1 = media_uri.MediaUri(loc)
@@ -461,6 +473,3 @@ class TestMediaURI(ElisaTestCase):
         uri2.set_param('ciao', 'bao')
         self.assertEqual(uri2.get_param('ciao'), 'bao')
         self.assertEqual(uri1.get_param('ciao'), 'miao')
-
-    if platform.system() == 'Windows':
-        test_smb.skip = 'not implemented for windows'
