@@ -14,10 +14,9 @@
 # for details on that license.
 
 from elisa.core.tests.elisa_test_case import ElisaTestCase
-from elisa.core import common, plugin
+from elisa.core import common
 from elisa.core import media_manager, metadata_manager, media_uri
-from elisa.core import media_db
-from elisa.base_components import media_provider, metadata_provider
+from elisa.core.components import media_provider, metadata_provider
 
 from twisted.internet import defer, threads
 
