@@ -16,7 +16,7 @@
 from twisted.trial import unittest
 from elisa.core.tests.elisa_test_case import ElisaTestCase, BoilerPlateApp
 from elisa.core import common, player_engine_registry, player, media_uri
-from elisa.base_components import player_engine
+from elisa.core.components import player_engine
 
 from elisa.core.player import STATES
 
