@@ -16,11 +16,11 @@
 
 from twisted.trial import unittest
 from elisa.core.tests.elisa_test_case import ElisaTestCase
-from elisa.core import common, player_engine_registry, plugin
+from elisa.core import common, player_engine_registry
 
 from elisa.core.player import STATES
 
-from elisa.base_components import player_engine
+from elisa.core.components import player_engine
 
 import gst
 
