@@ -17,7 +17,7 @@
 from twisted.trial import unittest
 from elisa.core.tests.elisa_test_case import ElisaTestCase
 from elisa.core import common, player_engine_registry, plugin
-from elisa.base_components import player_engine
+from elisa.core.components import player_engine
 
 class FooEngine(player_engine.PlayerEngine):
     uri_schemes = {'foo' : 150, 'test' : 100, 'test2' : 50 }
