@@ -85,16 +85,3 @@ class TestMisc(ElisaTestCase):
         self.assertEquals(misc.un_camelify('Foo Bar'), 'foo_bar')
         self.assertEquals(misc.un_camelify('fooBar'), 'foo_bar')
 
-    def test_get_media_infos_from_mime(self):
-        
-        if platform.system() == 'Windows':
-            raise unittest.SkipTest("Does not works under windows, need investigation")
-
-        uris = {'file://./foo.mp3': ('audio/mpeg', 'audio'),
-                'file://./test.ogg': ('application/ogg', 'audio'),
-                'file://./test.ogm': ('', 'video'),
-                'file:///tmp': ('', '')
-                }
-        for uri, expected in uris.iteritems():
-            infos = misc.get_media_infos_from_mime(media_uri.MediaUri(uri))
-            self.assertEquals(infos, expected)
