@@ -32,7 +32,8 @@ from elisa.core.utils import i18n
 from elisa.extern import path
 
 import setuptools
-from setuptools import setup, find_packages
+from setuptools import setup
+from setuptools import Distribution as SetuptoolsDistribution
 from setuptools.command.bdist_egg import bdist_egg
 from setuptools.command import test
 from setuptools.command import sdist
@@ -43,9 +44,25 @@ from distutils.core import Command
 from distutils.command import clean
 
 from twisted.scripts import trial
+import pkg_resources
 
 PACKAGE_DATA = {'': ['*.conf', '*.png', '*.mo', '*.po', '*.xml', '*.lirc']}
 
+class Distribution(SetuptoolsDistribution):
+
+    def find_config_files(self):
+        files = SetuptoolsDistribution.find_config_files(self)
+
+        # look for setup.cfg in the directory containing the setup.py
+        # (not current directory as in default's distutils
+        # Distribution)
+        setup_py = sys.argv[0]
+        project_dir = os.path.dirname(setup_py)
+        setup_cfg = os.path.join(project_dir, 'setup.cfg')
+        if os.path.exists(setup_cfg):
+            files.append(setup_cfg)
+        return files
+
 class SDist(sdist.sdist):
 
     def make_distribution(self):
@@ -189,6 +206,7 @@ setuptools.dist.check_test_suite = override_check_test_suite
 
 def write_dict(cmd, basename, filename, force=False):
     """
+    DOCME
     """
     argname = os.path.splitext(basename)[0]
     arg_value = getattr(cmd.distribution, argname, None)
@@ -199,112 +217,119 @@ def write_dict(cmd, basename, filename, force=False):
             text_value += "%s = %s\n" % (key, value)
     cmd.write_or_delete_file(argname, filename, text_value, force)
 
+
+def mappings_from_text(text):
+    """
+    Unserialise mappings from a string L{text}. Mappings are list of
+    2-uplets.
+
+    Example:
+
+        key1 = value1
+        key2 = value2a
+        key2 = value2b
+
+    is deserialised into:
+
+        [("key1", "value1"), ("key2", "value2a"), ("key2", "value2b")]
+    """
+    mappings = []
+    if text != None:
+        for line in text.splitlines():
+            m = tuple([elt.strip() for elt in line.split('=')])
+            if len(m) != 2: 
+                raise ValueError
+            mappings.append(m)
+
+    return mappings
+
+def text_from_mappings(mappings):
+    """
+    Takes a L{mappings} and return a serialised form. Mappings are list of
+    2-uplets.
+
+    Example:
+
+        [("key1", "value1"), ("key2", "value2a"), ("key2", "value2b")]
+
+    is serialised into:
+
+        key1 = value1
+        key2 = value2a
+        key2 = value2b
+
+    """
+    text = ""
+    if mappings != None:
+        for key, value in mappings:
+            text += "%s = %s%s" % (key, value, os.linesep)
+
+    return text
+
+def read_mappings(iter_lines):
+    """
+    Setuptools compliant deserialiser for mappings.
+    """
+    text = os.linesep.join(iter_lines)
+    return mappings_from_text(text)
+
+def write_mappings(cmd, basename, filename, force=False):
+    """
+    Setuptools compliant serialiser for mappings.
+    """
+    argname = os.path.splitext(basename)[0]
+    arg_value = getattr(cmd.distribution, argname, None)
+    text_value = text_from_mappings(arg_value)
+    cmd.write_or_delete_file(argname, filename, text_value, force)
+
+def assert_list_of_string_tuples_or_none(dist, attr, value):
+    """Verify that value is a list of tuples of string"""
+    if type(value) is types.NoneType:
+        return
+    if type(value) is list:
+        for item in value:
+            valid = type(item) is tuple and all([type(e) is str for e in item])
+            if not valid:
+                raise DistutilsSetupError("%r must be a list of tuples of string or "\
+                                          "None value. Got %r" % (attr,value))
+
 def assert_dict_or_none(dist, attr, value):
     """Verify that value is a dictionary"""
     if type(value) not in (dict, types.NoneType):
         raise DistutilsSetupError("%r must be a dictionary or None value. "\
                                   "Got %r" % (attr,value))
 
-def scan_plugin_conf(conf_path, name_prefix='elisa-plugin-'):
-    """ Read the config located at given path and return data suitable
-    to distutils' setup().
+def find_packages_internal(path='.'):
+    path = os.path.abspath(path)
 
-    @param conf_path:   absolute or relative path to a plugin.conf file
-    @type conf_path:    string
-    @param name_prefix: plugin's name prefix
-    @type name_prefix:  string
-    @rtype:             dict
-    """
-    cfg = config.Config(conf_path)
-    section = cfg.get_section('general')
+    if os.path.isdir(os.path.join(path, 'elisa')):
+        return setuptools.find_packages(path)
 
-    # Basic distutils supported keywords
-    name = section.get('name', default='unknown')
-    version = section.get('version', default='0.1')
-    description = section.get('description', default='no description')
-    long_description = section.get('long_description', default=description)
-    author = section.get('author', default='John Doe')
-    author_email = section.get('author_email', default='john@doe.com')
-    keywords = ','.join(section.get('keywords', default=[]))
-    license = section.get('license', default='UNKNOWN')
-    bundles = section.get('bundles', default=[])
-    replaces = section.get('replaces', default=[])
+    dirname = os.path.split(path)[1]
+    package = 'elisa.plugins.%s' % dirname
+    packages = [package]
+
+    packages += ['%s.%s' % (package, p) 
+            for p in setuptools.find_packages(path)]
+   
+    return packages
+
+def find_packages(path='.'):
+    packages = find_packages_internal(path)
+
+    if 'elisa' in packages:
+        return packages, {}
     
-    # Elisa specific metadata, to go in elisa_infos.txt 
-    category_id = section.get('category_id', default='unknown')
-    plugin_deps = [d.strip() for d in
-                   section.get('plugin_dependencies', default=[])]
-    py_deps = section.get('external_dependencies', default=[])
-    ext_deps = []
-    for component_path, component_config in cfg.as_dict().iteritems():
-        if component_path == 'general':
-            continue
-        for dep in component_config.get('external_dependencies',[]):
-            dep = dep.strip()
-            if dep not in ext_deps:
-                ext_deps.append(dep)
+    path = os.path.abspath(path)
+    dirname = os.path.split(path)[1]
+    package = 'elisa.plugins.%s' % dirname
 
-    py_deps = ','.join(py_deps)
-    ext_deps = ','.join(ext_deps)
-    bundles = ','.join(bundles)
-    replaces = ','.join(replaces)
-    
-    # TODO: eventually move categories to distutils trove classifiers
-    elisa_infos = {'category_id': category_id, 'py_deps': py_deps,
-                   'ext_deps': ext_deps, 'plugin_name': name,
-                   'replaces': replaces, 'bundles': bundles}
-        
-    conf_dir = os.path.dirname(conf_path)
-    if not conf_dir:
-        conf_dir = os.getcwd()
-        
-    package_name = os.path.basename(conf_dir)
-
-    if conf_dir == os.getcwd():
-        plugin_pkg_name = 'elisa.plugins.%s' % package_name
-        packages = [plugin_pkg_name,]
-        packages.extend(['%s.%s' % (plugin_pkg_name, p)
-                         for p in find_packages()])
-
-        tmp_dir = tempfile.mkdtemp()
-        f = open(os.path.join(tmp_dir, '__init__.py'), 'w')
-        f.write("""\
-__import__('pkg_resources').declare_namespace(__name__)
-
-from pkgutil import extend_path
-__path__ = extend_path(__path__, __name__)
-""")
-        f.close()
-        
-        infos = {'package_dir': {'elisa.plugins.%s' % package_name: '.',
-                                 'elisa':tmp_dir, 'elisa.plugins': tmp_dir,
-                                 },
-                 'py_modules': ['elisa.__init__', 'elisa.plugins.__init__']
-                 }
-    else:
-        infos = {}
-        packages = find_packages()
-        tmp_dir = None
-        
-    package_path = 'elisa.plugins.%s' % package_name
-    entry_points = {'elisa.plugins': ['%s = %s'  % (name, package_path),]}
-
-    requires = ['%s%s' % (name_prefix, n) for n in plugin_deps]
-    
-    infos.update({'name': '%s%s' % (name_prefix, name),
-                  'description': description, 'license': license,
-                  'keywords': keywords,
-                  'version': version, 'long_description': long_description,
-                  'author': author, 'author_email': author_email,
-                  'elisa_infos': elisa_infos, 'packages': packages,
-                  'namespace_packages': ['elisa.plugins',],
-                  'entry_points': entry_points,
-                  'install_requires': requires, 
-                  'package_data': PACKAGE_DATA,
-                  'cmdclass': CMD_CLASS,
-                  })
-    return tmp_dir, infos
+    packages.extend(['elisa', 'elisa.plugins'])
+    init_dir = pkg_resources.resource_filename('elisa.core',
+            'tests/data/namespace_init')
+    package_dir = {package: path, 'elisa': init_dir, 'elisa.plugins': init_dir}
 
+    return packages, package_dir
 
 def find_plugins(bundle_name, plugins_dir='.', prefix='', excludes=()):
     entry_points = []
@@ -390,14 +415,6 @@ __path__ = extend_path(__path__, __name__)
 
     shutil.rmtree(tmp_dir, ignore_errors=True)
 
-def run_plugin_setup(plugin_conf='plugin.conf'):
-    tmpdir, infos = scan_plugin_conf(plugin_conf)
-    
-    setup(**infos)
-
-    shutil.rmtree(tmpdir, ignore_errors=True)
-
-
 class bdist_elisa(bdist_egg):
     """
     A customized bdist_egg command that creates .elisa.egg files. They
@@ -414,44 +431,20 @@ class bdist_elisa(bdist_egg):
 
 class build_po(Command):
     """
-    Read a set of Elisa translation files, compile po files existing
-    in the directories listed in those files and ship mo files as
-    package_data of the distribution.
-
-    Translation files have the following format::
-    
-      #
-      # domain path/to/input /path/to/output
-      # other-domain path/to/input/only
-      #
-      #
-      # Don't forget the empty line at the end!
-
+    Compile po files to mo files and ship mo files as package_data of
+    the distribution.
     """
 
     description = "compile Elisa translation file(s)"
+    user_options = []
 
-    user_options = [
-        ('trans-files=', 't', 'Elisa translation files')
-        ]
+    def finalize_options(self):
+        pass
 
-    
     def initialize_options(self):
-        self.trans_files = []
+        pass
 
-    def finalize_options (self):
-        self.ensure_filename_list('trans_files')
-        if not self.trans_files:
-            self.trans_files = ['data/translations.lst',]
-            
     def run(self):
-        mo_files = i18n.compile_translations_from_files(self.trans_files)
+        mo_files = i18n.compile_po_files(self.distribution.get_name(), 'i18n', 'i18n',
+                                         announce_func=self.announce)
         self.distribution.package_data.update(mo_files)
-
-    def ensure_filename_list(self, option):
-        self.ensure_string_list(option)
-        for fname in getattr(self, option):
-            if not os.path.exists(fname):
-                msg = "'%s' does not exist or is not a file" % fname
-                raise DistutilsOptionError("error in '%s' option: %s" % (option,
-                                                                         msg))
