@@ -26,6 +26,8 @@ import sys, platform
 import os, re
 from twisted.internet import defer
 
+import pkg_resources
+
 def env_var_expand(var_name):
     """
     Expand the given environment variable content. If it contains
@@ -113,49 +115,6 @@ def un_camelify(camel_string):
                 un_cameled += letter
     return un_cameled
 
-def get_media_infos_from_mime(uri):
-    """
-    Retrieve mime-type and media type of the given URI, based on its
-    extension.
-
-    DEPRECATED !!!
-
-    @param uri: the media resource address to analyze
-    @type uri:  L{elisa.core.media_uri.MediaUri}
-    @rtype:     2-tuple: (mime_type: string, file_type: string)
-    """
-    pass
-    # TODO: remove this function when mime_getter works
-    mime_type = mimetypes.guess_type(uri.path)
-    if mime_type[0]:
-        parts = mime_type[0].split('/')
-        mime_type = mime_type[0]
-        # Special cases handling
-        if parts[0] == 'application':
-            ext = uri.extension
-            custom_extensions = {'ogg': 'audio',
-                                 }
-            file_type = custom_extensions.get(ext, '')
-        else:
-            file_type = parts[0]
-
-        blacklist = ['x-mpegurl',]
-        if parts[1] in blacklist:
-            mime_type = ''
-            file_type = ''
-    else:
-        # in case mimetypes did not return anything, filter on extension
-        custom_extensions = {'flv': 'video',
-                             'ogm': 'video',
-                             'mkv': 'video',
-                             'mod': 'video',
-                             'nef': 'image'
-                             }
-        file_type = custom_extensions.get(uri.extension, '')
-        if mime_type == (None, None):
-            mime_type = ''
-    return mime_type, file_type
-
 # cache the result of the first is_hildon_desktop_running call
 _hildon_desktop_running = None
 
@@ -177,7 +136,7 @@ def is_hildon_desktop_running():
             dbus.BUS_DAEMON_PATH, dbus.BUS_DAEMON_IFACE)
         iface = dbus.Interface(driver, dbus.BUS_DAEMON_IFACE)
         _hildon_desktop_running = \
-            bool(iface.NameHasOwner('com.nokia.hildon-desktop'))
+            bool(iface.NameHasOwner('org.moblin.SystemDaemon'))
     except dbus.DBusException:
         # it fails so we assume it is not hildon
         _hildon_desktop_running = False
@@ -187,26 +146,58 @@ def is_hildon_desktop_running():
 
 def get_distro():
     DISTROS = {
-	"Ubuntu" : "/etc/lsb-release",
-	"Debian" : "/etc/debian_version",
-	#"RedHat" : "/etc/redhat-release",
-	"SUSE" : "/etc/SUSE-release",
-	"Fedora" : "/etc/fedora-release",
-	"Gentoo" : "/etc/gentoo-release",
-	"Slackware" : "/etc/slackware-version",
-	"Mandriva" : "/etc/mandriva-release",
-	"Mandrake" : "/etc/mandrake-release",
-	"YellowDog" : "/etc/yellowdog-release",
-	"SUN JDS" : "/etc/sun-release",
-	"UnitedLinux" : "/etc/UnitedLinux-release"
-	}
-	
-    for name,location in DISTROS.iteritems():
-	try:
-	    distroFile = open("%s" % location,"r")
-	    content = distroFile.readlines(); distroFile.close();
-	except:
-	    pass
-	else:
-	    return name
-    return 'Unknown'	
+        "Ubuntu" : "/etc/lsb-release",
+        "Debian" : "/etc/debian_version",
+        #"RedHat" : "/etc/redhat-release",
+        "SUSE" : "/etc/SUSE-release",
+        "Fedora" : "/etc/fedora-release",
+        "Gentoo" : "/etc/gentoo-release",
+        "Slackware" : "/etc/slackware-version",
+        "Mandriva" : "/etc/mandriva-release",
+        "Mandrake" : "/etc/mandrake-release",
+        "YellowDog" : "/etc/yellowdog-release",
+        "SUN JDS" : "/etc/sun-release",
+        "UnitedLinux" : "/etc/UnitedLinux-release"
+    }
+
+    for name, location in DISTROS.iteritems():
+        if os.path.exists(location):
+            return name
+    return 'Unknown'
+
+
+def get_os_name():
+    distro = get_distro()
+    if distro != "Unknown":
+        return distro
+    else:
+        return platform.system().lower()
+
+
+def pkg_resources_copy_dir(resource_spec, resource_dir, dest_dir):
+    """
+    Copy a directory recursively using pkg_resources.
+    """
+    assert pkg_resources.resource_isdir(resource_spec, resource_dir)
+
+    # add '' at the end so that working_dir ends with a slash
+    working_dir = os.path.join(dest_dir, '')
+
+    pkg_resources.ensure_directory(working_dir)
+
+    for rel_entry in pkg_resources.resource_listdir(resource_spec, resource_dir):
+        # rel_entry is relative to resource_dir
+        entry = os.path.join(resource_dir, rel_entry)
+
+        if pkg_resources.resource_isdir(resource_spec, entry):
+            dest_entry = os.path.join(dest_dir, rel_entry)
+            pkg_resources_copy_dir(resource_spec, entry, dest_entry)
+            continue
+
+        working_file = os.path.join(working_dir, rel_entry)
+        resource_stream = pkg_resources.resource_stream(resource_spec, entry)
+        
+        out = file(working_file, 'w')
+        out.write(resource_stream.read())
+        out.close()
+        resource_stream.close()
