@@ -18,6 +18,7 @@
 __maintainer__ = 'Florian Boucault <florian@fluendo.com>'
 __maintainer2__ = 'Philippe Normand <philippe@fluendo.com>'
 
+import weakref
 
 class WrongArgument(Exception):
     """ Exception raised by Signal when the developer tries to emit
@@ -99,6 +100,7 @@ class Signal(object):
         self._args_types = args_types
         self._kw_types = kw_types
         self._receivers = []
+        self._arguments = weakref.WeakKeyDictionary()
 
     def __repr__(self):
         """ Textual representation of the Signal
@@ -109,7 +111,7 @@ class Signal(object):
         r = '<Signal %s with %d receivers>' % (self._name, len(self._receivers))
         return r
 
-    def connect(self, receiver):
+    def connect(self, receiver, *args, **kw):
         """
         Connect a receiver to the signal. It will be called when the signal
         is emitted.
@@ -117,11 +119,15 @@ class Signal(object):
         @param receiver:      object to be called when the signal is emitted
         @type receiver:       callable
 
+        @param params:        parameters to send to the receiver when calling
+        @param kw:            keywords to send to the receiver when calling
+
         @exception TypeError: raised if the receiver is not callable
         """
         if callable(receiver):
-            if receiver not in self._receivers:
-                self._receivers.append(receiver)
+            if receiver not in [receiver() for receiver in self._receivers]:
+                self._receivers.append( weakref.ref(receiver) )
+                self._arguments[receiver] = (args, kw)
         else:
             raise TypeError("Receiver is not a callable")
 
@@ -132,12 +138,13 @@ class Signal(object):
         @param receiver:      object to be disconnected
         @type receiver:       callable
 
-        @exception Exception: raised if the receiver is not connected
+        @raise IndexError: raised if the receiver is not in the list of
+                           receivers
         """
-        try:
-            self._receivers.remove(receiver)
-        except:
-            raise Exception("%s not connected to the signal" % receiver)
+        index = [ current_receiver() for current_receiver in
+                                        self._receivers].index(receiver)
+        self._receivers.pop(index)
+        self._arguments.pop(receiver)
 
     def emit(self, *args, **kw):
         """
@@ -155,8 +162,37 @@ class Signal(object):
         """
         self._check_args_types(args, kw)
 
+        # filter out the dropped ones
+        filter(lambda receiver: receiver() != None, self._receivers)
+
         for receiver in self._receivers:
-            receiver(*args, **kw)
+            real_receiver = receiver()
+            if real_receiver is None:
+                # should happen rarely but can happen: the receiver was
+                # removed AFTER we filtered...
+                continue
+
+            # try to get arguments and keyword
+            this_args, this_kw = self._arguments.get(real_receiver, (None, None) )
+
+            # create our copy of the data
+            send_args = args
+            send_kw = {}
+
+            if this_args is not None and len(args) > 0:
+                # if there are argument then merge it
+                send_args += this_args
+
+            if this_kw is not None:
+                # if there are parameters, merge them
+                send_kw.update(this_kw)
+
+            # needs to be done AFTER maybe merges because we want the same
+            # ones to get overwritten!
+            send_kw.update(kw)
+
+            # FIXME: other receivers do not get proceeded if one fails
+            real_receiver(*send_args, **send_kw)
 
     def _check_args_types(self, args, kw):
         """ Check the types of arguments and keywords comply with
